summaryrefslogtreecommitdiff
path: root/src/storage.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/storage.h')
-rw-r--r--src/storage.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/storage.h b/src/storage.h
index 534eca0a..6a844320 100644
--- a/src/storage.h
+++ b/src/storage.h
@@ -292,11 +292,11 @@ class Storage
std::list<std::string> getEmailList() = 0;
/**
* Return if an Email is already in account's table.
* @return true if Email already exists.
*/
- virtual bool
- doesEmailAlreadyExists(const std::string &email) = 0;
+ virtual unsigned int
+ getSameEmailNumber(const std::string &email) = 0;
/**
* Tells if the character's name already exists
@@ -292,11 +292,11 @@ class Storage
std::list<std::string> getEmailList() = 0;
/**
- * Return if an Email is already in account's table.
- * @return true if Email already exists.
+ * Return the number of same Emails in account's table.
+ * @return Number of same Email.
*/